# Define the kmod package name here.
%define kmod_name wl

# If kversion isn't defined on the rpmbuild line, define it here as the currently running kernel.
%{!?kversion: %define kversion $(uname -r)}

Name:    %{kmod_name}-kmod
Version: 6_30_223_248
Release: 3%{?dist}
Group:   System Environment/Kernel
License: Broadcom
Summary: %{kmod_name} kernel module(s)
URL:     http://www.broadcom.com/support/802.11/linux_sta.php

BuildRequires: redhat-rpm-config, kernel-abi-whitelists, perl
ExclusiveArch: x86_64

# Sources.
#Source0:  hybrid-v35-nodebug-pcoem-%{version}.tar.gz
Source1:  hybrid-v35_64-nodebug-pcoem-%{version}.tar.gz
Source2:  README_6.30.223.248.txt
Source10: kmodtool-%{kmod_name}-el7.sh

# Ensure that the tarballs ARE NOT packaged.
#NoSource: 0
NoSource: 1

# Patches.
Patch0:  wl-kmod-fix-ioctl-handling.patch
Patch1:  wl-kmod-rhel7_1.patch

# Magic hidden here.
%{expand:%(sh %{SOURCE10} rpmtemplate %{kmod_name} %{kversion} "")}

# Disable the building of the debug package(s).
%define debug_package %{nil}

%description
This package provides the Broadcom hybrid %{kmod_name} kernel module(s).
It is built to depend upon the specific ABI provided by a range of releases
of the same variant of the Linux kernel and not on any one specific build.

%prep
%setup -q -n %{kmod_name}-kmod-%{version} -c -T
#%ifarch i686
#%setup -q -D -T -a 0
#%endif
%ifarch x86_64
%setup -q -D -T -a 1
%endif
%patch0 -p1
%patch1 -p1

# Create the module override file.
echo "override %{kmod_name} * weak-updates/%{kmod_name}" > kmod-%{kmod_name}.conf

# Create the file to blacklist certain modules.
%{__cat} <<EOF > blacklist-Broadcom.conf
blacklist b43
blacklist b43legacy
blacklist bcm43xx
blacklist brcmsmac
blacklist ssb
blacklist bcma
EOF

# Create the file to modprobe the modules at system initialisation time.
%{__cat} <<EOF > kmod-%{kmod_name}.modules
#!/bin/bash

for M in lib80211 cfg80211 wl; do
    modprobe $M &>/dev/null
done
EOF

%build
if [ "%{apiwext}" == "1" ]
then
    %{__make} KBUILD_DIR=%{_usrsrc}/kernels/%{kversion} API=WEXT
else
    %{__make} KBUILD_DIR=%{_usrsrc}/kernels/%{kversion}
fi

%install
%{__install} -d %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
%{__install} %{kmod_name}.ko %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
%{__install} -d %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} kmod-%{kmod_name}.conf %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} -d %{buildroot}/usr/lib/modprobe.d/
%{__install} blacklist-Broadcom.conf %{buildroot}/usr/lib/modprobe.d/
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig/modules/
%{__install} kmod-%{kmod_name}.modules %{buildroot}%{_sysconfdir}/sysconfig/modules/
%{__install} -d %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/
%{__install} %{SOURCE2} %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/README.txt
%{__install} lib/LICENSE.txt %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/

# Strip the modules(s).
find %{buildroot} -type f -name \*.ko -exec %{__strip} --strip-debug \{\} \;

# Sign the modules(s).
%if %{?_with_modsign:1}%{!?_with_modsign:0}
# If the module signing keys are not defined, define them here.
%{!?privkey: %define privkey %{_sysconfdir}/pki/SECURE-BOOT-KEY.priv}
%{!?pubkey: %define pubkey %{_sysconfdir}/pki/SECURE-BOOT-KEY.der}
for module in $(find %{buildroot} -type f -name \*.ko);
do %{__perl} /usr/src/kernels/%{kversion}/scripts/sign-file \
    sha256 %{privkey} %{pubkey} $module;
done
%endif

%clean
%{__rm} -rf %{buildroot}

%changelog
* Sat Mar 14 2015 Philip J Perry <phil@elrepo.org> - 6_30_223_248-3
- Update for RHEL7.1 [http://elrepo.org/bugs/view.php?id=559]

* Tue Jul 22 2014 The Doctor <DrWho@Gallifrey.Kasterborus> - 6_30_223_248-2
- Corrected the path to the /modprobe.d/ directory.

* Mon Jul 21 2014 The Doctor <DrWho@Gallifrey.Kasterborus> - 6_30_223_248-1
- Initial el7 build of the kmod package.
